Initial values, parameters, direct modules, differential modules, and a differential equation solver that can be used to run Miscanthus x giganteus growth simulations in Champaign, Illinois and other locations.
To represent Miscanthus growth in Champaign, IL, these values must be
paired with the Champaign weather data (cmi_weather_data). The
parameters already include the clay_loam values from the
soil_parameters dataset, which is the appropriate soil type for
Champaign.
Some specifications, such as the values of photosynthetic parameters, would remain the same in any location; others, such as the latitude or longitude, would need to change when simulating crop growth in different locations. Care must be taken to understand each input quantity before attempting to run simulations in other places or for other cultivars.
miscanthus_x_giganteusA list of 5 named elements that are suitable for passing to
run_biocro, as described in the help page for
crop_model_definitions.
run_biocro
modules
crop_model_definitions